@@ -17,6 +17,7 @@ from . import (
     concentrations,
     convert,
     equilibria,
+    extra,
     meta,
     original,
     solve,
@@ -26,6 +27,7 @@ __all__ = [
     'concentrations',
     'convert',
     'equilibria',
+    'extra',
     'meta',
     'original',
     'solve',
@@ -485,6 +487,23 @@ def _CO2SYS(PAR1, PAR2, PAR1TYPE, PAR2TYPE, SAL, TEMPIN, TEMPOUT, PRESIN,
     # Calculate the pKs at output
     pK1o = -log10(K1o)
     pK2o = -log10(K2o)
+    
+    # Evaluate ESM10 buffer factors (corrected following RAH18) [added v1.2.0]
+    gammaTCi, betaTCi, omegaTCi, gammaTAi, betaTAi, omegaTAi = \
+        extra.buffers_ESM10(TCc, TAc, CO2inp, HCO3inp, CARBic, PHic, OHinp,
+                            BAlkinp, KBi)
+    gammaTCo, betaTCo, omegaTCo, gammaTAo, betaTAo, omegaTAo = \
+        extra.buffers_ESM10(TCc, TAc, CO2out, HCO3out, CARBoc, PHoc, OHout,
+                            BAlkout, KBo)
+        
+    # Evaluate (approximate) isocapnic quotient [HDW18] and psi [FCG94]
+    # [added v1.2.0]
+    isoQi = extra.bgc_isocap(CO2inp, PHic, K1i, K2i, KBi, KWi, TB)
+    isoQxi = extra.bgc_isocap_approx(TCc, PCic, K0i, K1i, K2i)
+    psii = extra.psi(CO2inp, PHic, K1i, K2i, KBi, KWi, TB)
+    isoQo = extra.bgc_isocap(CO2out, PHoc, K1o, K2o, KBo, KWo, TB)
+    isoQxo = extra.bgc_isocap_approx(TCc, PCoc, K0o, K1o, K2o)
+    psio = extra.psi(CO2out, PHoc, K1o, K2o, KBo, KWo, TB)
 
     # Save data directly as a dict to avoid ordering issues
     CO2dict = {
@@ -582,6 +601,25 @@ def _CO2SYS(PAR1, PAR2, PAR1TYPE, PAR2TYPE, SAL, TEMPIN, TEMPOUT, PRESIN,
         'TB': TB*1e6,
         'TF': TF*1e6,
         'TS': TS*1e6,
+        # Added in v1.2.0:
+        'gammaTCin': gammaTCi,
+        'betaTCin': betaTCi,
+        'omegaTCin': omegaTCi,
+        'gammaTAin': gammaTAi,
+        'betaTAin': betaTAi,
+        'omegaTAin': omegaTAi,
+        'gammaTCout': gammaTCo,
+        'betaTCout': betaTCo,
+        'omegaTCout': omegaTCo,
+        'gammaTAout': gammaTAo,
+        'betaTAout': betaTAo,
+        'omegaTAout': omegaTAo,
+        'isoQin': isoQi,
+        'isoQout': isoQo,
+        'isoQapprox_in': isoQxi,
+        'isoQapprox_out': isoQxo,
+        'psi_in': psii,
+        'psi_out': psio,
     }
     return CO2dict
 
